const pkg = require(`../package.json`);
const Spritesmith = require(`spritesmith`);
const fs = require(`fs`);
const aPath = require(`path`);
const Datauri = require(`datauri`).sync;
const getFolders = (dir) => {
  return fs.readdirSync(dir).filter((file) => {
    return fs.statSync(aPath.join(dir, file)).isDirectory();
  });
};

const target = `sass/make/base64/_map.scss`;
const imgPath = `base64/make/base64.png`;

let base64Data = new String();
let filePath;
let file;
let property;
let x;
let y;
let xx;
let yy;
let w;
let h;
let W;
let H;
let img;
let folder;
let filenameList = [];
let filenameParam = ``;

const writeData = (str) => {
  fs.writeFileSync(target, str);
};

fs.readdir(`base64`, (err, list) => {
  try {
    if (aPath.extname(list.toString(10)) !== `.png`) {
      writeData(`$base64-sprites: null;\n`);
      return;
    }

    let pngs = [];

    for (let i = 0; i < list.length; i++) {
      /\.png$/.test(list[i]) ? pngs.push(`base64/${list[i]}`) : null;
    }

    Spritesmith.run(
      {
        src: pngs,
        algorithm: `binary-tree`,
        padding: 6,
      },
      (handleResult = (err, result) => {
        if (err) {
          throw err;
        }

        fs.writeFile(imgPath, result.image, () => {
          for (let n in result.coordinates) {
            filePath = n.split(`/`);
            file = filePath[1].split(`.`)[0];
            property = `$${file}: (`;
            x = `${result.coordinates[n].x}px, `;
            y = `${result.coordinates[n].y}px, `;
            xx = `-${x}`;
            yy = `-${y}`;
            w = `${result.coordinates[n].width}px, `;
            h = `${result.coordinates[n].height}px, `;
            W = `${result.properties.width}px, `;
            H = `${result.properties.height}px, `;
            img = `'${imgPath}', `;
            folder = `'${file}', );\n`;
            base64Data += property + x + y + xx + yy + w + h + folder;
            filenameList.push(file);
          }

          for (let i = 0; i < filenameList.length; i++) {
            filenameParam = `${filenameParam}$${filenameList[i]}, `;
          }

          base64Data += `$base64-sprites: (${filenameParam});\n`;
          base64Data += `$base64: (${W}${H}${img}$base64-sprites, );\n`;
          base64Data += `%base64 { background: url(${Datauri(imgPath)}); }\n`;
          writeData(base64Data);
        });
      })
    );
  } catch (err) {
    console.log(`no base64 folder`);
    writeData(`$base64-sprites: null;\n`);
  }
});
